/*
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights reserved.
 *
 * Author: TCSDeveloper
 */

using System;
using System.IO;
using NUnit.Framework;

namespace TopCoder.Rules.DependencyMap.View
{   
    /// <summary>
    /// Failure test fixture for DependencyRenderer.
    /// </summary>
    [TestFixture]
    public class DependencyRendererTests
    {
        private SVGRenderer svgr = new SVGRenderer(".");
        
        /// <summary>
        /// Test constructor with null.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testCon_Null() 
        {
            new DependencyRenderer(null);
        }

        /// <summary>
        /// Test constructor with valid input.
        /// </summary>
        [Test]
        public void testCon_Silent() 
        {
            new DependencyRenderer(new ShapeFactory());            
        }
        
        /// <summary>
        /// Test add with null DR.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testAdd_Null() 
        {
            new DependencyRenderer().AddDiagramRenderer(null);
        }
        
        /// <summary>
        /// Test remove with null DR.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testRem_Null() 
        {
            new DependencyRenderer().RemoveDiagramRenderer(null);
        }

        /// <summary>
        /// Test remove with good DR.
        /// </summary>
        public void testRem_Silent() 
        {
            new DependencyRenderer().RemoveDiagramRenderer(svgr);
        }

        /// <summary>
        /// Test remove with null DR.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testSet_Null() 
        {
            new DependencyRenderer().LayoutManager = (null);
        }
        
        /// <summary>
        /// Test remove with DR.
        /// </summary>
        [Test]
        public void testSet_Silent() 
        {
            new DependencyRenderer().LayoutManager = (new FixedGridLayoutManager());
        }
        
        /// <summary>
        /// Test render with null DR.
        /// </summary>
        [Test]
        [ExpectedException(typeof(ArgumentNullException))]
        public void testRender_Null() 
        {
            new DependencyRenderer().Render(null);
        }
    }
}
